.route--active{font-weight:700;text-decoration:underline}html{font-family:sans-serif;line-height:1.15;-ms-text-size-adjust:100%;-webkit-text-size-adjust:100%}body{margin:0}article,aside,footer,header,nav,section{display:block}h1{font-size:2em;margin:.67em 0}figcaption,figure,main{display:block}figure{margin:1em 40px}hr{box-sizing:content-box;height:0;overflow:visible}pre{font-family:monospace,monospace;font-size:1em}a{background-color:transparent;-webkit-text-decoration-skip:objects}a:active,a:hover{outline-width:0}abbr[title]{border-bottom:none;text-decoration:underline;text-decoration:underline dotted}b,strong{font-weight:inherit;font-weight:bolder}code,kbd,samp{font-family:monospace,monospace;font-size:1em}dfn{font-style:italic}mark{background-color:#ff0;color:#000}small{font-size:80%}sub,sup{font-size:75%;line-height:0;position:relative;vertical-align:baseline}sub{bottom:-.25em}sup{top:-.5em}audio,video{display:inline-block}audio:not([controls]){display:none;height:0}img{border-style:none}svg:not(:root){overflow:hidden}button,input,optgroup,select,textarea{font-family:sans-serif;font-size:100%;line-height:1.15;margin:0}button,input{overflow:visible}button,select{text-transform:none}[type=reset],[type=submit],button,html [type=button]{-webkit-appearance:button}[type=button]::-moz-focus-inner,[type=reset]::-moz-focus-inner,[type=submit]::-moz-focus-inner,button::-moz-focus-inner{border-style:none;padding:0}[type=button]:-moz-focusring,[type=reset]:-moz-focusring,[type=submit]:-moz-focusring,button:-moz-focusring{outline:1px dotted ButtonText}fieldset{border:1px solid silver;margin:0 2px;padding:.35em .625em .75em}legend{box-sizing:border-box;color:inherit;display:table;max-width:100%;padding:0;white-space:normal}progress{display:inline-block;vertical-align:baseline}textarea{overflow:auto}[type=checkbox],[type=radio]{box-sizing:border-box;padding:0}[type=number]::-webkit-inner-spin-button,[type=number]::-webkit-outer-spin-button{height:auto}[type=search]{-webkit-appearance:textfield;outline-offset:-2px}[type=search]::-webkit-search-cancel-button,[type=search]::-webkit-search-decoration{-webkit-appearance:none}::-webkit-file-upload-button{-webkit-appearance:button;font:inherit}details,menu{display:block}summary{display:list-item}canvas{display:inline-block}[hidden],template{display:none}html{box-sizing:border-box}body,html{margin:0;padding:0;height:100%}*,:after,:before{box-sizing:inherit}.inputs-container{padding:10px 20px;border-radius:3px;display:inline-block}.inputs-container .input-container{display:inline-block;margin:10px;border-radius:3px;overflow:hidden;opacity:.3;cursor:pointer;width:100px;height:100px;box-shadow:0 5px 10px rgba(0,0,0,.1);transition:all .15s ease}.inputs-container .input-container.selected-input,.inputs-container .input-container:hover{opacity:1}.dash-loader{padding:150px;text-align:center}.dash-message{color:rgba(0,0,0,.5);text-align:center;padding:50px;background-color:rgba(0,0,0,.01);border-radius:3px;border:1px solid rgba(0,0,0,.1);max-width:500px;margin:100px auto}.layer-img-container{display:inline-block;margin:0 2px;border-radius:3px;overflow:hidden;position:relative;width:100px;height:100px}.layer-img-container .layer-img-img{position:absolute;top:0;left:0;width:100%;height:100%}.layer-img-container .layer-output{transition:all .5s}.layer-img-container .layer-output:hover{opacity:.5}.layer-img-container:hover{opacity:1}.layer-info-container{position:fixed;left:0;bottom:0;z-index:99;background-color:hsla(0,0%,100%,.95);margin:20px;box-shadow:0 5px 10px rgba(0,0,0,.1);transition:all .15s ease;border:1px solid rgba(0,0,0,.1);max-width:30%;border-radius:3px}.layer-info-container .layer-name{color:rgba(0,0,0,.5);padding:30px}.layer-info-container .layer-config{max-height:300px;overflow:auto}.layer-info-container .layer-config pre{padding:40px!important;background-color:rgba(0,0,0,.02)!important;border:1px solid rgba(0,0,0,.1)!important;margin:0}.output-container{margin-top:20px}.collapse-expand-btn{margin-top:-20px;padding:10px;font-weight:lighter;cursor:pointer;opacity:.5;float:right;font-size:2em;transition:all .15s ease}.collapse-expand-btn:hover{opacity:1}.predictions-container{padding:15px}.prediction-container{display:inline-block;margin:5px 15px;background-color:#fff;box-shadow:0 5px 10px rgba(0,0,0,.1);padding:15px;border-radius:3px;border:1px solid rgba(0,0,0,.2);opacity:.8}.prediction-container:hover{opacity:1}.prediction-container .confidence{color:#1758c1}.graph-vis-container{min-height:1000px}.graph-container{position:fixed;left:0;top:0;width:40%;height:1000px;background-color:#fff;z-index:99}.experiment-container{width:60%;position:absolute;right:0;top:0;background-color:rgba(0,0,0,.01);border-left:1px solid rgba(0,0,0,.1);min-height:100%;padding:30px}.output-container{text-align:center}